@@ -15,9 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from typing import TYPE_CHECKING, Sequence
+
 from airflow.providers.mongo.hooks.mongo import MongoHook
 from airflow.sensors.base import BaseSensorOperator
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class MongoSensor(BaseSensorOperator):
     """
@@ -27,6 +32,7 @@ class MongoSensor(BaseSensorOperator):
     >>> mongo_sensor = MongoSensor(collection="coll",
     ...                            query={"key": "value"},
     ...                            mongo_conn_id="mongo_default",
+    ...                            mongo_db="admin",
     ...                            task_id="mongo_sensor")
 
     :param collection: Target MongoDB collection.
@@ -36,9 +42,11 @@ class MongoSensor(BaseSensorOperator):
     :param mongo_conn_id: The :ref:`Mongo connection id <howto/connection:mongo>` to use
         when connecting to MongoDB.
     :type mongo_conn_id: str
+    :param mongo_db: Target MongoDB name.
+    :type mongo_db: str
     """
 
-    template_fields = ('collection', 'query')
+    template_fields: Sequence[str] = ('collection', 'query')
 
     def __init__(
         self, *, collection: str, query: dict, mongo_conn_id: str = "mongo_default", mongo_db=None, **kwargs
@@ -49,7 +57,7 @@ class MongoSensor(BaseSensorOperator):
         self.query = query
         self.mongo_db = mongo_db
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: 'Context') -> bool:
         self.log.info(
             "Sensor check existence of the document that matches the following query: %s", self.query
         )
